/*
   Joystick functions
   --------------------------------------------------------------------
   Linberto

   Copyright (C) 1999-2001 Diego Javier Grigna <diego@grigna.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

/* It should be done in the configuration menu in the future. */
#define JOY_CAL_ERR 64

struct timeval last_sample;
int can_move;

void joy_init( void)
{

 errno = 0;

 if( joystick_init(0, JOY_CALIB_STDOUT) < 0) {
     if( opt.cfg_joystick == LIN_JOYSTICK_ON) {
         fprintf( stderr,
           _("\njoystick_init: Unable to initialize joystick 0: %s.\n\n"), 
           errno == 0 ? " " : strerror( errno)
                );
         opt.cfg_joystick = LIN_JOYSTICK_OFF;
     }
 }

 last_sample.tv_sec = 0;
 last_sample.tv_usec = 0;
 can_move = 1;
}

int joy_moved( void)
{
 int x, y;
 int retval = 0;

 if( opt.cfg_joystick == LIN_JOYSTICK_OFF)
     return 0;

 if( joystick_update() == 0)
     return 0;

// if( joy_can_get_sample() == 0)
//     return 0;

 x = joystick_getx();
 y = joystick_gety();

 if( joy_equal( x) && joy_equal( y)) {
     can_move = 1;
 }

 if( can_move) {
     if( joy_more( x) && joy_more( y)) {
         lin_scancode = SCANCODE_KEYPAD3;
         retval = 1;
     }

     if( joy_less( x) && joy_less( y)) {
         lin_scancode = SCANCODE_KEYPAD7;
         retval = 1;
     }

     if( joy_more( x) && joy_less( y)) {
         lin_scancode = SCANCODE_KEYPAD9;
         retval = 1;
     }
     
     if( joy_less( x) && joy_more( y)) {
         lin_scancode = SCANCODE_KEYPAD1;
         retval = 1;
     }

     if( joy_equal( x) && joy_more( y)) {
         lin_scancode = SCANCODE_KEYPAD2;
         retval = 1;
     }

     if( joy_equal( x) && joy_less( y)) {
         lin_scancode = SCANCODE_KEYPAD8;
         retval = 1;
     }

     if( joy_equal( y) && joy_more( x)) {
         lin_scancode = SCANCODE_KEYPAD6;
         retval = 1;
     }

     if( joy_equal( y) && joy_less( x)) {
         lin_scancode = SCANCODE_KEYPAD4;
         retval = 1;
     }

     if( retval)
         can_move = 0;
 }
 
 if( joystick_getb1()) {
     lin_scancode = SCANCODE_ENTER;
     retval = 1;
 }

 if( joystick_getb2()) {
     lin_scancode = SCANCODE_ESCAPE;
     retval = 1;
 }

 if( joystick_getb3()) {
     lin_scancode = SCANCODE_SPACE;
     retval = 1;
 }

 return retval;
}

int joy_button_enter( void)
{
 if( opt.cfg_joystick == LIN_JOYSTICK_OFF)
     return 0;

 if( joystick_update() == 0)
     return 0;

 if( joy_can_get_sample() == 0)
     return 0;

 if( joystick_getb1()) {
     lin_scancode = SCANCODE_ENTER;
     return 1;
 }

 return 0;
}

int joy_button_any( void)
{
 if( opt.cfg_joystick == LIN_JOYSTICK_OFF)
     return 0;

 if( joystick_update() == 0)
     return 0;

 if( joy_can_get_sample() == 0)
     return 0;

 if( joystick_getb1()) {
     lin_scancode = SCANCODE_ENTER;
     return 1;
 }

 if( joystick_getb2()) {
     lin_scancode = SCANCODE_ESCAPE;
     return 1;
 }

 return 0;
}

int joy_can_get_sample( void)
{
 struct timeval curr_sample;
 long sample;

 gettimeofday( &curr_sample, ( struct timezone *) NULL);

 if( curr_sample.tv_sec != last_sample.tv_sec) {
     last_sample.tv_sec  = curr_sample.tv_sec;
     last_sample.tv_usec = curr_sample.tv_usec;
     return 1;
 }

 sample = curr_sample.tv_usec - last_sample.tv_usec;

 if( sample < 0 || sample > 50000) {
     last_sample.tv_sec  = curr_sample.tv_sec;
     last_sample.tv_usec = curr_sample.tv_usec;
     return 1;
 }

 return 0;
}

int joy_equal( int value)
{
 if( value >= ( JOY_CAL_ERR * -1) && value <= JOY_CAL_ERR)
     return 1;

 return 0;
}

int joy_more( int value)
{
 if( value > JOY_CAL_ERR)
     return 1;

 return 0;
}

int joy_less( int value)
{
 if( value < (JOY_CAL_ERR * -1))
     return 1;

 return 0;
}


