/*
   i18n and l10n functions
   --------------------------------------------------------------------
   Linberto

   Copyright (C) 1999-2001 Diego Javier Grigna <diego@grigna.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

/* Used to restore the LANGUAGE environment variable if it exists. */
char *nls_restore;

/* 
 * Initialize the NLS stuff
 */

void nls_init( void)
{
 nls_restore = getenv( "LANGUAGE");

 setlocale( LC_ALL, "");
 bindtextdomain( PACKAGE, LOCALEDIR);
 textdomain( PACKAGE);

 opt.cfg_language = nls_get_default_language();
 nls_change_language();
}

void nls_change_language( void)
{
 switch( opt.cfg_language) {
         case LIN_LANGUAGE_ENGLISH: setenv( "LANGUAGE", "en_US", 1); break;
         case LIN_LANGUAGE_SPANISH: setenv( "LANGUAGE", "es"   , 1); break;
         case LIN_LANGUAGE_ITALIAN: setenv( "LANGUAGE", "it"   , 1); break;
         case LIN_LANGUAGE_GERMAN : setenv( "LANGUAGE", "de"   , 1); break;
 }

 /* Make change known. */
 {
  extern int _nl_msg_cat_cntr;
  ++_nl_msg_cat_cntr;
 }

}

void nls_exit( void)
{
 if( nls_restore != NULL)
     setenv( "LANGUAGE", nls_restore, 1);
}

int nls_get_default_language( void)
{
 char *lclstr;

 lclstr = getenv( "LANG");
 
 if( lclstr == NULL)
     return DEFAULT_LANGUAGE;

 if( !strncasecmp( lclstr, "es", 2))
     return LIN_LANGUAGE_SPANISH;

 if( !strncasecmp( lclstr, "it", 2))
     return LIN_LANGUAGE_ITALIAN;

 if( !strncasecmp( lclstr, "de", 2))
     return LIN_LANGUAGE_GERMAN;

 if( !strncasecmp( lclstr, "en", 2))
     return LIN_LANGUAGE_ENGLISH;

 return DEFAULT_LANGUAGE;
}


