/*
   Sound functions
   --------------------------------------------------------------------
   Linberto

   Copyright (C) 1999-2001 Diego Javier Grigna <diego@grigna.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

/* Global variables */

int send_sound_flag; /* Did the sound server forked? */

static int lastchannel;
static char *sound_path;
static Sample samples[ SND_MAX];

/* Function prototypes */
static void sound_load( void);
static void sound_read_fromfile( int sndnum, char *file);

void sound_init( void)
{

 /* if ENABLE_SOUND == 0 then who compiled the binary doesn't want
    to fork the sound server */

 if( !ENABLE_SOUND) {
     opt.cfg_sound   = SOUND_OFF;
     send_sound_flag = SOUND_SERVER_OFF;
     return;
 }

 lastchannel = 0;

 /* Suppose everything will be allright. */
 send_sound_flag = SOUND_SERVER_ON;

 /* Load sound files */
 sound_load();

 if( Snd_init( SND_MAX, samples, 8000, SOUND_CHANNELS, LINBERTO_SOUNDDEV) == -1) {
     opt.cfg_sound   = SOUND_OFF;
     send_sound_flag = SOUND_SERVER_OFF;
 }

}

void sound_off( void)
{
 fprintf( stderr, _("\nTurning sound server off...\n\n"));
 opt.cfg_sound   = SOUND_OFF;
 send_sound_flag = SOUND_SERVER_OFF;
}

void sound_send( int snd_number)
{
 if( opt.cfg_sound == SOUND_OFF)
     return;

 if( send_sound_flag == SOUND_SERVER_OFF)
     return;

 lastchannel++;
 if( lastchannel > SOUND_CHANNELS - 2)
     lastchannel = 0;

 Snd_effect( snd_number, lastchannel);
}

void sound_music( int snd_number)
{
 if( opt.cfg_sound == SOUND_OFF)
     return;

 if( send_sound_flag == SOUND_SERVER_OFF)
     return;

 Snd_effect( snd_number, SOUND_CHANNELS - 1);
}

static void sound_load( void)
{
 sound_path = LINBERTO_SNDDIR;

 if( access( sound_path, F_OK) == -1) {
     fprintf( stderr, _("\nCan't access dir: %s: %s\n\nThe game is not installed. Trying default sound dir...\n\n"), sound_path, strerror( errno));
     sound_path = LINBERTO_SNDDIR_DEFAULT;
     if( access( sound_path, F_OK) == -1) {
         fprintf( stderr, _("\nCan't access default sound dir: %s: %s\n\n"), sound_path, strerror( errno));
         exit_game( 1);
     }
 }

 /* Music */
 sound_read_fromfile( SND_WELCOME, SND_WELCOME_FILE);

 /* The following is needed to shut down the music */
 samples[ SND_NONE].data = (unsigned char *) "N";
 samples[ SND_NONE].len  = 0;

 sound_read_fromfile( SND_BKGDM  , SND_BKGDM_FILE);

 /* Sound FX */
 sound_read_fromfile( SND_DEATH  , SND_DEATH_FILE  );
 sound_read_fromfile( SND_JUMP   , SND_JUMP_FILE   );
 sound_read_fromfile( SND_SPLAT  , SND_SPLAT_FILE  );
 sound_read_fromfile( SND_FPJP   , SND_FPJP_FILE   );
 sound_read_fromfile( SND_BUBJP  , SND_BUBJP_FILE  );
 sound_read_fromfile( SND_CHANGE , SND_CHANGE_FILE );
 sound_read_fromfile( SND_FALL   , SND_FALL_FILE   );
 sound_read_fromfile( SND_MENU   , SND_MENU_FILE   );
 sound_read_fromfile( SND_BUBK   , SND_BUBK_FILE   );
 sound_read_fromfile( SND_BLKD   , SND_BLKD_FILE   );
 sound_read_fromfile( SND_BLKF   , SND_BLKF_FILE   );
 sound_read_fromfile( SND_BLKM   , SND_BLKM_FILE   );
 sound_read_fromfile( SND_BLKN   , SND_BLKN_FILE   );
}

static void sound_read_fromfile( int sndnum, char *file)
{
 char buffer[ 2048];

 sprintf( buffer, "%s/%s", sound_path, file);

 if( Snd_loadRawSample( buffer, &samples[ sndnum]) < 0) {
     fprintf( stderr, _("\nCan't open file [%s]: %s\n\nPlaying without this sound.\n\n"), buffer, strerror( errno));
 }
}

void sound_shutdown( void)
{
 if( send_sound_flag == SOUND_SERVER_OFF)
     return;

 Snd_restore();
}

